{% import "partials/_variables.jinja" as theme -%}

{%- with theme=theme -%}
<!doctype html>
<html {% if language %}lang="{{ language }}" {% endif %}class="no-js">
  <head>
    {%- include "!partials/_head.html" -%}
  </head>
  <body dir="{{ direction }}">
    {% block body -%}
    {%- include "!partials/body-prefix.html" -%}
    {%- include "!partials/announce.html" -%}
    {%- include "!partials/header.html" -%}
    <main class="container">
      {% block content %}
      {%- include "!partials/content.html" with context -%}
      {% endblock %}
    </main>
    {%- include "!partials/footer.html" -%}
    {%- include "!partials/body-suffix.html" -%}
    {%- endblock -%}
  </body>
</html>
{%- endwith -%}
