html{height:100%;scroll-behavior:smooth;font-family:"Roboto", sans-serif;font-size:100%;overflow-x:hidden}@media (min-width: 1600px){html{font-size:110%}}@media (min-width: 2000px){html{font-size:137.50%}}body{margin:0;padding:0}header{z-index:1;position:sticky;top:0;width:100vw}main{padding-top:1.5rem}.container{flex-grow:1;width:100%;max-width:75rem;display:flex;margin-left:auto;margin-right:auto}.content{flex-grow:1;flex-shrink:0;max-width:100%}@media (min-width: 960px){.content{max-width:calc(100% - 15.1rem)}}@media (min-width: 1220px){.content{max-width:calc(100% - 15.1rem * 2)}}.content article{padding:1rem}.content article *:target{scroll-margin-top:3.625rem}.hamburger{display:block;position:relative}.hamburger i{position:relative;display:block;width:18px;height:2px;margin:3px 0;background:white}header{height:3.125rem;display:flex;align-items:center;background-color:#4051b5;color:white;box-shadow:0 0 0.2rem rgba(0,0,0,0);transition:box-shadow 500ms;font-size:1.125rem;line-height:3rem;font-weight:300;display:block;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}header.scrolled{box-shadow:0 0 0.2rem rgba(0,0,0,0.1),0 0.2rem 0.4rem rgba(0,0,0,0.2)}header .container,.header-primary,.header-secondary,.header-logo,.header-title{display:flex;align-items:center;height:100%}header .container{justify-content:space-between}.header-primary,.header-title{flex-grow:1}.header-primary>*,.header-secondary>*{margin:0 1rem}.header-primary>:nth-child(1),.header-secondary>:nth-child(1){margin-left:0.5rem}.header-logo img{height:1.5rem}.header-title{position:relative;height:100%;width:100%}.header-page-title,.header-overall-title{transition:transform 400ms cubic-bezier(0.1, 0.7, 0.1, 1),opacity 150ms}.header-overall-title{opacity:1;transform:translateX(0)}.scrolled-content .header-overall-title{z-index:-1;opacity:0;transform:translateX(-1rem)}.header-page-title{position:absolute;left:0;z-index:-1;opacity:0;transform:translateX(1rem)}.scrolled-content .header-page-title{z-index:1;opacity:1;transform:translateX(0)}@media (min-width: 1220px){.hamburger{display:none}}@media (max-width: 1219.98px){.header-logo{display:none}}a.clean-link{color:inherit;text-decoration:none}footer a[href]{color:white}footer .container{flex-direction:row;justify-content:space-between;align-items:center;height:100%}.footer-nav{background-color:rgba(0,0,0,0.87);height:6rem}.footer-info{font-size:0.75rem;line-height:1.3rem;background-color:black;height:4rem}.footer-meta{color:grey}.footer-meta .highlight{color:white}.footer-icons{color:white}.sidebar{flex:0 0 15rem;background:white}.sidebar-scroll{position:-webkit-sticky;position:sticky;top:3.125rem}.sidebar-content{padding:1rem 0.5rem;font-size:.85rem}.sidebar-content ul{list-style-type:none;margin-top:0;padding-left:0.75rem}.sidebar-content li{padding-top:0.7rem}.sidebar-content li .current.reference{font-weight:bold}.sidebar-content>ul{padding-left:0}.sidebar-content a,.sidebar-content a:visited{color:inherit;text-decoration:none}.sidebar-content a:hover{color:purple}.caption{margin-top:0.7rem;margin-bottom:0;font-weight:bold}.sidebar-left{position:fixed;top:0;left:-15rem;width:15rem;min-height:100vh;transition:left 250ms}@media (min-width: 1220px){.sidebar-left{position:initial;top:initial;left:initial}}.overlay{position:fixed;top:0;left:0;height:0;width:0;opacity:0;transition:width 0ms, height 0ms, opacity 250ms;background-color:rgba(0,0,0,0.54)}@media (max-width: 1219.98px){#__drawer:checked~.sidebar-left{left:0;z-index:4}#__drawer:checked~.overlay{z-index:3;width:100%;height:100%;opacity:1}}.sidebar-right{display:none}.sidebar-right .sidebar-content>ul>li{padding-top:0}.sidebar-right .sidebar-content>ul>li>ul{padding-left:0}.sidebar-right .sidebar-content>ul>li>a{display:none}.sidebar-right .scroll-past>a{opacity:0.5}.sidebar-right .scroll-current>a{color:#4051b5}@media (min-width: 960px){.sidebar-right{display:initial;order:1}}h1{margin-top:0.5rem}
