{# For the sidebar drawer show up. #}
<input type="checkbox" id="__drawer" name="name" hidden/>
<label class="overlay" for="__drawer"></label>

<!-- TODO: Navigation -->
<div class="sidebar sidebar-left">
  <div class="sidebar-scroll">
    <div class="sidebar-content">
      {% set global_toc = toctree(collapse=false, includehidden=false, titles_only=true) %}
      {{ global_toc }}
    </div>
  </div>
</div>
<div class="sidebar sidebar-right">
  <div class="sidebar-scroll">
    <div class="sidebar-content">
      {% if toc %}
      <p class="caption"><span class="caption-text">Table of Contents</span></p>
      {{ toc }}
      {% endif %}
    </div>
  </div>
</div>
<div class="content">
  <article>{{ body }}</article>
</div>
