#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['materialism']

package_data = \
{'': ['*'],
 'materialism': ['partials/*',
                 'scss/*',
                 'static/*',
                 'static/scripts/*',
                 'static/scripts/vendor/*',
                 'static/stylesheets/*']}

package_dir = \
{'': 'src'}

extras_require = \
{'doc': ['sphinx'], 'test': ['pytest', 'pytest-cov', 'pytest-xdist']}

entry_points = \
{'sphinx.html_themes': ['materialism = materialism']}

setup(name='materialism',
      version='0.1.2',
      description='A Material Design theme for Sphinx (inspired by mkdocs-material).',
      author='Pradyun Gedam',
      author_email='mail@pradyunsg.me',
      url='https://github.com/pradyunsg/materialism',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.5',
     )
