<header>
<div class="container">

{# Left hand side #}
<div class="header-primary">
  {% if logo %}
  <a class="header-logo clean-link" href="{{ pathto(master_doc) }}">
    <img src="{{ pathto('_static/' + logo, 1) }}" alt="Logo"/>
  </a>
  {% endif %}
  <label class="hamburger" for="__drawer">
    <i></i><i></i><i></i>
  </label>
  <div class="header-title">
      <div class="header-overall-title">
        <a class="clean-link" href="{{ pathto(master_doc) }}">
          {{ docstitle }}
        </a>
        </div>
      <div class="header-page-title">{{ title }}</div>
  </div>
</div>

{# Right hand side #}
<div class="header-secondary">
  <a class="clean-link" href="{{ pathto('search') }}">Search</a>
</div>

<!-- TODO: Make this fade away to h1-content, like mkdocs-material -->
<!-- TODO: Tabs? -->
<!-- TODO: RHS repo/page/RTD information? -->

</div>
</header>
