{# Colours

  primary: material colour name or hex
  secondary: material colour name or hex
  background: "light", "dark", "preference"
  include_css: boolean

#}
{% set colour = none %}

{# Fonts

  heading: ...
  prose: ...
  code: ...

#}
{% set font = {
  "heading": "Roboto",
  "prose": "Roboto",
  "code": "Roboto Mono",
} %}
